;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "nasm-mode" "1.2.0"
  "NASM x86 assembly major mode."
  '((emacs "24.3"))
  :url "https://github.com/skeeto/nasm-mode"
  :commit "fab76d8e092419c341b6240fcc7123975db177e1"
  :revdesc "fab76d8e0924"
  :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
  :maintainers '(("Christopher Wellons" . "wellons@nullprogram.com")))
